@@ -9,7 +9,7 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.32_03';
+$VERSION = '0.32_04';
 
 %EXPORT_TAGS = (
     'all' => [qw(
@@ -24,12 +24,25 @@ $VERSION = '0.32_03';
 bootstrap UUID $VERSION;
 
 sub import {
-    # :persist=FOO
     for (my $i=scalar(@_)-1 ; $i>0 ; --$i) {
         my $v = $_[$i];
+        # :persist=FOO
         if (length($v) > 9 and substr($v,0,9) eq ':persist=') {
             _persist(substr($v, 9));
             splice @_, $i, 1;
+            next;
+        }
+        # :mac=random
+        if (length($v) == 11 and $v eq ':mac=random') {
+            _hide_mac();
+            splice @_, $i, 1;
+            next;
+        }
+        # :mac=unique
+        if (length($v) == 11 and $v eq ':mac=unique') {
+            _hide_always();
+            splice @_, $i, 1;
+            next;
         }
     }
     goto &Exporter::import;
@@ -160,21 +173,17 @@ I</dev/random> in non-blocking mode.
 
 =head2 B<generate_time(> I<$uuid> B<)>
 
-Generates a new version 1 binary UUID which uses the current time and the
+Generates a new version 1 binary UUID using the current time and the
 local ethernet MAC address, if available.
 
-If the MAC address is not available at startup, it is generated randomly
-and used through the lifetime of the process. The multicast bit of this
-address is set to avoid conflict with addresses returned from network
-cards.
+If the MAC address is not available at startup, or a randomized address
+is requested (see B<:mac> in B<EXPORTS>), a random address is used. The
+multicast bit of this address is set to avoid conflict with addresses
+returned from network cards.
 
-This algorithm used to be the default used to generate UUIDs, but
-because of inclusion of the ethernet MAC address, it can leak
-information about where the UUID was generated.
-
-This can cause privacy problems in some applications, so the
-B<generate()> function only uses this algorithm if a high-quality source
-of randomness is not available.
+This algorithm used to be the default for generating UUIDs, but because
+of privacy concerns, the B<generate()> function only uses it if a
+high-quality source of randomness is not available.
 
 =head2 B<generate_v1(> I<$uuid> B<)>
 
@@ -295,9 +304,25 @@ making the randomized parts 62 bits wide at start.
 None by default. All functions may be imported in the usual manner,
 either individually or all at once using the B<:all> tag.
 
+=head2 B<:mac>=I<mode>
+
+The MAC address used for v1 UUIDS is forced to always be random in
+one of two modes:
+
+=over 4
+
+I<random> The MAC address is generated once at startup and used
+throughout the lifetime of the process.
+
+I<unique> A new MAC address is generated for each new UUID. It is not
+guaranteed to be unique beyond the probability of randomness.
+
+=back
+
 =head2 B<:persist>=F<path/to/state.txt>
 
 Path to version 1 state maintenance file. (See B<MAINTAINING STATE>.)
+The path may be either relative or absolute.
 
 If the file does not exist, it will be created provided the path
 exists.
@@ -305,9 +330,9 @@ exists.
 If the file cannot be opened, cannot be created, or is a symlink, UUID
 will ignore it. No state will be maintained.
 
-B<WARNING>: Do not point B<:persist> into a public directory. See
-CVE-2013-4184. UUID attempts to avoid this, but nothing is foolproof.
-Only YOU can prevent symlink attacks!
+B<WARNING>: Do not B<:persist> in a public directory. See CVE-2013-4184.
+UUID attempts to avoid this, but nothing is foolproof. Only YOU can
+prevent symlink attacks!
 
 =head1 THREAD SAFETY
 
