@@ -4,6 +4,8 @@
 #
 # Patch to:
 #   - Add explicit casts to silence warnings.
+#   - Fixup includes.
+#   - Move to uuconfig.h.
 #
 use strict;
 use warnings;
@@ -29,9 +31,26 @@ print $out;
 exit 0;
 
 __END__
---- usrcP/uuid/parse.c	Sat Dec  9 02:18:40 2023
-+++ ulib/uuid/parse.c	Sat Dec  9 03:00:51 2023
-@@ -64,15 +64,15 @@
+--- usrcP/uuid/parse.c	Sun Jan 14 15:29:18 2024
++++ ulib/uuid/parse.c	Sun Jan 14 15:36:21 2024
+@@ -32,14 +32,9 @@
+  * %End-Header%
+  */
+ 
+-#include "config.h"
+-#include <stdlib.h>
+-#include <stdio.h>
+-#include <ctype.h>
+-#include <string.h>
++#include "uuconfig.h"
++#include "uuid/uuidP.h"
+ 
+-#include "uuidP.h"
+-
+ int myuuid_parse(const char *in, myuuid_t uu)
+ {
+ 	struct myuuid	uuid;
+@@ -64,15 +59,15 @@
  			return -1;
  	}
  	uuid.time_low = strtoul(in, NULL, 16);
