@@ -2,7 +2,7 @@
 # Patch given file with DATA hunks and print to STDOUT.
 #
 #
-# Patching types in unpack.c.
+# Patch to localize.
 #
 use strict;
 use warnings;
@@ -28,16 +28,16 @@ print $out;
 exit 0;
 
 __END__
-diff -aurN usrcP/uuid/unpack.c usrcP.targ/uuid/unpack.c
---- usrcP/uuid/unpack.c	2023-12-02 17:58:13.893295000 +0200
-+++ usrcP.targ/uuid/unpack.c	2023-12-02 15:28:51.790114000 +0200
+--- usrc/uuid/unpack.c	Wed Nov 29 23:03:41 2023
++++ usrcP/uuid/unpack.c	Wed Dec  6 00:39:17 2023
 @@ -35,11 +35,12 @@
  #include "config.h"
  #include <string.h>
  #include "uuidP.h"
 +#include <uuid/uuid_types.h>
  
- void uuid_unpack(const uuid_t in, struct uuid *uu)
+-void uuid_unpack(const uuid_t in, struct uuid *uu)
++void myuuid_unpack(const myuuid_t in, struct myuuid *uu)
  {
 -	const uint8_t	*ptr = in;
 -	uint32_t		tmp;
@@ -46,3 +46,4 @@ diff -aurN usrcP/uuid/unpack.c usrcP.targ/uuid/unpack.c
  
  	tmp = *ptr++;
  	tmp = (tmp << 8) | *ptr++;
+
