@@ -9,6 +9,8 @@
 #   - Fixup includes.
 #   - Add xo_rand().
 #   - Add xo_srand().
+#   - Add myuuid_hide_mac().
+#   - Add myuuid_hide_always().
 #
 use strict;
 use warnings;
@@ -34,8 +36,8 @@ print $out;
 exit 0;
 
 __END__
---- ulib/uuid/uuid.h.new	Fri Jan 12 02:57:45 2024
-+++ ulib/uuid/uuid.h	Sat Jan 13 22:30:30 2024
+--- ulib/uuid/uuid.h.new	Sun Jan 14 20:07:34 2024
++++ ulib/uuid/uuid.h	Wed Jan 17 05:08:21 2024
 @@ -35,11 +35,8 @@
  #ifndef _UUID_UUID_H
  #define _UUID_UUID_H
@@ -50,13 +52,17 @@ __END__
  
  typedef unsigned char myuuid_t[16];
  
-@@ -79,6 +76,9 @@
+@@ -79,6 +76,13 @@
  void myuuid_generate(myuuid_t out);
  void myuuid_generate_random(myuuid_t out);
  void myuuid_generate_time(myuuid_t out);
 +void myuuid_init_statepath(const char *path);
 +myuint64_t xo_rand(void);
 +void xo_srand(void);
++int myuuid_node_or_fail(unsigned char *dest);
++void myuuid_node_or_rand(unsigned char *dest);
++void myuuid_hide_mac(void);
++void myuuid_hide_always(void);
  
  /* isnull.c */
  int myuuid_is_null(const myuuid_t uu);
