@@ -3,8 +3,10 @@
 #
 #
 # Patch to:
-#   * Include Windows.h.
-#   * Cast to silence warning.
+#   - Include Windows.h.
+#   - Cast to silence warning.
+#   - Fixup includes.
+#   - Move to uuconfig.h.
 #
 use strict;
 use warnings;
@@ -30,20 +32,33 @@ print $out;
 exit 0;
 
 __END__
---- usrcP/uuid/uuid_time.c	Sat Dec  9 02:18:40 2023
-+++ ulib/uuid/uuid_time.c	Sat Dec  9 02:50:06 2023
-@@ -46,6 +46,10 @@
- #include <sys/time.h>
- #endif
- #include <time.h>
-+#ifdef HAVE_WINDOWS_H
-+#include <Windows.h>
-+#include <stdint.h>
-+#endif
+--- usrcP/uuid/uuid_time.c	Sun Jan 14 15:29:18 2024
++++ ulib/uuid/uuid_time.c	Sun Jan 14 15:30:20 2024
+@@ -34,21 +34,9 @@
+  * %End-Header%
+  */
  
- #include "uuidP.h"
+-#include "config.h"
++#include "uuconfig.h"
++#include "uuid/uuidP.h"
  
-@@ -62,7 +66,7 @@
+-#include <stdio.h>
+-#ifdef HAVE_UNISTD_H
+-#include <unistd.h>
+-#endif
+-#include <stdlib.h>
+-#include <sys/types.h>
+-#ifdef HAVE_SYS_TIME_H
+-#include <sys/time.h>
+-#endif
+-#include <time.h>
+-
+-#include "uuidP.h"
+-
+ time_t myuuid_time(const myuuid_t uu, struct timeval *ret_tv)
+ {
+ 	struct timeval		tv;
+@@ -62,7 +50,7 @@
  	clock_reg = uuid.time_low | ((myuint64_t) high << 32);
  
  	clock_reg -= (((myuint64_t) 0x01B21DD2) << 32) + 0x13814000;
